@@ -19,11 +19,7 @@ limitations under the License.
 #include <Rinternals.h>
 #include <R_ext/Rdynload.h>
 
-/* fun.c functions */
-extern SEXP address(SEXP);
-extern SEXP bsum(SEXP, SEXP);
-
-/* cgraph.c functions */
+// cgraph.c functions
 extern SEXP cgraph(SEXP, SEXP);
 extern SEXP cg_add_constant(SEXP, SEXP, SEXP);
 extern SEXP cg_add_input(SEXP, SEXP, SEXP);
@@ -32,14 +28,17 @@ extern SEXP cg_add_parameter(SEXP, SEXP, SEXP);
 extern SEXP cg_add_parms();
 extern SEXP cg_adj_mat(SEXP);
 extern SEXP cg_approx_grad(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP cg_gen_name(SEXP, SEXP);
+extern SEXP cg_gen_name(SEXP);
 extern SEXP cg_get_parms(SEXP);
 extern SEXP cg_gradients(SEXP, SEXP, SEXP, SEXP);
 extern SEXP cg_run(SEXP, SEXP, SEXP);
 
+// internal.c functions
+extern SEXP address(SEXP);
+extern SEXP bsum(SEXP, SEXP);
+
 static const R_CallMethodDef CallEntries[] = {
-  {"address",            (DL_FUNC) &address,            1},
-  {"bsum",               (DL_FUNC) &bsum,               2},
+  // cgraph.c functions
   {"cgraph",             (DL_FUNC) &cgraph,             2},
   {"cg_add_constant",    (DL_FUNC) &cg_add_constant,    3},
   {"cg_add_input",       (DL_FUNC) &cg_add_input,       3},
@@ -48,10 +47,14 @@ static const R_CallMethodDef CallEntries[] = {
   {"cg_add_parms",       (DL_FUNC) &cg_add_parms,       2},
   {"cg_adj_mat",         (DL_FUNC) &cg_adj_mat,         1},
   {"cg_approx_grad",     (DL_FUNC) &cg_approx_grad,     6},
-  {"cg_gen_name",        (DL_FUNC) &cg_gen_name,        2},
+  {"cg_gen_name",        (DL_FUNC) &cg_gen_name,        1},
   {"cg_get_parms",       (DL_FUNC) &cg_get_parms,       1},
   {"cg_gradients",       (DL_FUNC) &cg_gradients,       4},
   {"cg_run",             (DL_FUNC) &cg_run,             3},
+  // internal.c functions
+  {"address",            (DL_FUNC) &address,            1},
+  {"bsum",               (DL_FUNC) &bsum,               2},
+
   {NULL, NULL, 0}
 };
 
